"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const steps_1 = require("./steps");
const utils_1 = require("./utils");
function create(projectNameArg, options) {
    return __awaiter(this, void 0, void 0, function* () {
        // 1. Get all the required project information
        const { projectDisplayName, projectPath } = yield (0, steps_1.getProjectInfo)(projectNameArg);
        const relProjectPath = (0, utils_1.relative)(projectPath);
        const template = (0, steps_1.getTemplate)(options.template);
        const installCommand = yield (0, steps_1.getInstallCommand)(options.installer);
        // 2. Scaffold Project
        console.log('');
        utils_1.log.info(`Scaffolding ${utils_1.colors.bold(relProjectPath)} using  ${utils_1.colors.bold(template)} template`, 1);
        yield (0, steps_1.scaffoldTemplate)({
            projectPath,
            template
        });
        console.log('');
        utils_1.log.info(`Running ${utils_1.colors.bold(installCommand)}`, 2);
        // 3. Install Dependencies
        try {
            yield (0, utils_1.run)(installCommand, {
                cwd: projectPath
            });
        }
        catch (err) {
            utils_1.log.failure(`Could not install dependencies. Skipping ${installCommand}`);
        }
        // 4. Set name in project's package.json
        (0, steps_1.setNameInPackageJSON)(`${projectPath}/package.json`, projectDisplayName);
        // 5. Delete `.git` (For projects scaffolded from github)
        (0, utils_1.deleteDir)(`${projectPath}/.git`);
        // 6. Log Success
        utils_1.log.success(`${projectDisplayName} scaffolded successfully 🚀\n`);
        let runCommand = 'npm run dev';
        if (installCommand === 'yarn') {
            runCommand = 'yarn dev';
        }
        else if (installCommand === 'pnpm install') {
            runCommand = 'pnpm run dev';
        }
        utils_1.log.info(`${utils_1.colors.bold(`cd ${relProjectPath}`)} and run ${utils_1.colors.bold(runCommand)} to run the dev-server\n`);
    });
}
exports.default = create;
